Plugins/CheckerPlugins/Pep8/CodeStyleChecker.py

changeset 2980
2cb4e3c50b37
parent 2979
e2eee1b09664
--- a/Plugins/CheckerPlugins/Pep8/CodeStyleChecker.py	Tue Oct 01 18:34:19 2013 +0200
+++ b/Plugins/CheckerPlugins/Pep8/CodeStyleChecker.py	Tue Oct 01 18:42:42 2013 +0200
@@ -4,7 +4,7 @@
 #
 
 """
-Module implementing the PEP 8 checker.
+Module implementing the code style checker.
 """
 
 import os
@@ -23,7 +23,7 @@
 
 class CodeStyleCheckerPy2(object):
     """
     Class implementing the PEP 8 checker interface for Python 2.
     """
     def __init__(self, filename, lines, repeat=False,
                  select="", ignore="", max_line_length=79,
@@ -23,7 +23,7 @@
 class CodeStyleCheckerPy2(object):
     """
-    Class implementing the PEP 8 checker interface for Python 2.
+    Class implementing the code style checker interface for Python 2.
     """
     def __init__(self, filename, lines, repeat=False,

eric ide

mercurial